@@ -43,6 +43,7 @@ EXISTENT_SET = 101
 EXISTENT_QOS_RULE = 114
 INV_INPUT_BELOW_RANGE = 115
 INV_INPUT_QOS_TARGET_OBJECT = 117
+INV_OPERATION_VV_IN_REMOTE_COPY = 120
 NON_EXISTENT_TASK = 145
 INV_INPUT_VV_GROW_SIZE = 152
 VV_NEW_SIZE_EXCEED_CPG_LIMIT = 153
@@ -851,7 +852,7 @@ def create_snapshot(volume_name):
         valid_online_param_keys = {'online': None, 'destCPG': None,
                                    'tpvv': None, 'tdvv': None,
                                    'snapCPG': None, 'saveSnapshot': None,
-                                   'priority': None}
+                                   'priority': None, 'reduce': None}
         params = data['parameters']
         if 'online' in params and params['online']:
             # we are checking online copy
@@ -949,7 +950,7 @@ def create_volumes():
                   'tpvv': None, 'usrSpcAllocWarningPct': None,
                   'usrSpcAllocLimitPct': None, 'isCopy': None,
                   'copyOfName': None, 'copyRO': None, 'expirationHours': None,
-                  'retentionHours': None}
+                  'retentionHours': None, 'reduce': None}
 
     for key in list(data.keys()):
         if key not in list(valid_keys.keys()):
@@ -975,6 +976,11 @@ def create_volumes():
             throw_error(400, TOO_LARGE,
                         'Volume size is above architectural limit : 16TiB')
 
+    if 'tpvv' in list(data.keys()):
+        if data['tpvv'] not in [True, False, None]:
+            throw_error(400, INV_INPUT_WRONG_TYPE,
+                        'Invalid input:wrong type for value - tpvv')
+
     if 'id' in list(data.keys()):
         for vol in volumes['members']:
             if vol['id'] == data['id']:
@@ -1035,6 +1041,75 @@ def modify_volume(volume_name):
             break
 
     data = json.loads(flask.request.data.decode('utf-8'))
+
+    if 'online' in data and 'priority' in data:
+        throw_error(409, INV_INPUT_PARAM_CONFLICT,
+                    "invalid input: parameters cannot be present at the"
+                    " same time")
+
+    if len(remote_copy_groups['members']) != 0:
+        if data.get('action') == 4:
+            if data.get('allowRemoteCopyParent') is not True:
+                throw_error(403, INV_OPERATION_VV_IN_REMOTE_COPY,
+                            "Volume is involved in remote copy")
+
+    if data.get('action') == 4:
+        task['taskid'] = '12345'
+        resp = flask.make_response(json.dumps(task), 200)
+        return resp
+
+    if data.get('action') == 6:
+        valid_keys = {'action': None, 'tuneOperation': None, 'userCPG': None,
+                      'snapCPG': None, 'conversionOperation': None,
+                      'keepVV': None, 'compression': None}
+
+        for key in list(data.keys()):
+            if key not in list(valid_keys.keys()):
+                throw_error(400, INV_INPUT, "Invalid Parameter '%s'" % key)
+
+        if 'conversionOperation' in list(data.keys()):
+            if data['conversionOperation'] not in [1, 2, 3, 4]:
+                throw_error(400, INV_INPUT_WRONG_TYPE,
+                            "Invalid input:wrong type for value"
+                            " - conversionOperation")
+
+        if 'compression' in list(data.keys()):
+            if data['compression'] not in [True, False, None]:
+                throw_error(400, INV_INPUT_WRONG_TYPE,
+                            "Invalid input:wrong type for value"
+                            " - compression")
+
+        if 'tuneOperation' in list(data.keys()):
+            if data['tuneOperation'] not in [1, 2]:
+                throw_error(400, INV_INPUT_WRONG_TYPE,
+                            "Invalid input:wrong type for value"
+                            " - tuneOperation")
+
+        if 'keepVV' in list(data.keys()) and len(data['keepVV']) > 31:
+            throw_error(400, INV_INPUT_EXCEEDS_LENGTH,
+                        'Invalid Input: String length exceeds limit : keepVV')
+
+        conversion_operation = data.get('conversionOperation')
+        if conversion_operation == 1:
+            volume_type = 'tpvv'
+        elif conversion_operation == 2:
+            volume_type = 'fpvv'
+        elif conversion_operation == 3:
+            volume_type = 'tdvv'
+
+        if conversion_operation == 4:
+            if (volume.get('tdvv') is None or
+                    volume.get('tdvv') is False) and \
+               (volume.get('compression') is None or
+                    volume.get('compression') is False):
+                volume['tdvv'] = True
+                volume['compression'] = True
+        else:
+            if volume.get(volume_type) is None or \
+               volume.get(volume_type) is False:
+                volume[volume_type] = True
+        resp = flask.make_response(json.dumps(volume), 200)
+        return resp
     _grow_volume(volume, data)
 
     # do volume renames last
@@ -2188,6 +2263,9 @@ if __name__ == "__main__":
     qos_db = {'members': [],
               'total': 0}
 
+    global task
+    task = {"taskid": ''}
+
     global tasks
     tasks = {"total": 2, "members":
              [{"id": 8933, "type": 15, "name": "check_slow_disk",
