@@ -39,7 +39,7 @@ IQN2 = 'iqn.bogus.org.debian:01:0000' + hpe3parbase.TIME
 class HPE3ParClientHostTestCase(hpe3parbase.HPE3ParClientBaseTestCase):
 
     def setUp(self):
-        super(HPE3ParClientHostTestCase, self).setUp()
+        super(HPE3ParClientHostTestCase, self).setUp(withSSH=True)
 
     def tearDown(self):
         try:
@@ -288,7 +288,7 @@ class HPE3ParClientHostTestCase(hpe3parbase.HPE3ParClientBaseTestCase):
         self.cl.createHost(HOST_NAME1, None, fc, optional)
 
         host1 = self.cl.getHost(HOST_NAME1)
-        self.assertEquals(host1['name'], HOST_NAME1)
+        self.assertEqual(host1['name'], HOST_NAME1)
 
         self.printFooter('get_host')
 
@@ -304,7 +304,7 @@ class HPE3ParClientHostTestCase(hpe3parbase.HPE3ParClientBaseTestCase):
 
         # validate host was created
         host1 = self.cl.getHost(HOST_NAME1)
-        self.assertEquals(host1['name'], HOST_NAME1)
+        self.assertEqual(host1['name'], HOST_NAME1)
 
         # change host name
         mod_request = {'newName': HOST_NAME2}
@@ -312,7 +312,7 @@ class HPE3ParClientHostTestCase(hpe3parbase.HPE3ParClientBaseTestCase):
 
         # validate host name was changed
         host2 = self.cl.getHost(HOST_NAME2)
-        self.assertEquals(host2['name'], HOST_NAME2)
+        self.assertEqual(host2['name'], HOST_NAME2)
 
         # host 1 name should be history
         self.assertRaises(exceptions.HTTPNotFound, self.cl.getHost, HOST_NAME1)
@@ -644,3 +644,17 @@ class HPE3ParClientHostTestCase(hpe3parbase.HPE3ParClientBaseTestCase):
         self.assertIn(HOST_NAME1, [host['name'] for host in hosts['members']])
         self.assertIn(HOST_NAME2, [host['name'] for host in hosts['members']])
         self.printFooter('query_host_iqn_and_wwn')
+
+    def test_6_find_host(self):
+        self.printHeader('find_host_wwn')
+
+        hosts = self.cl.findHost(wwn=WWN1)
+
+        if hosts is not None:
+            # host found
+            self.assertIsNotNone(hosts)
+        else:
+            # host not found
+            self.assertIsNone(hosts)
+
+        self.printFooter('find_host_wwn')
